# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.models.objs_file import ObjsFile

class TestObjsFile(unittest.TestCase):
    """ObjsFile unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ObjsFile:
        """Test ObjsFile
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ObjsFile`
        """
        model = ObjsFile()
        if include_optional:
            return ObjsFile(
                channels = [
                    'CQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                    ],
                comments_count = 56,
                created = 56,
                date_delete = 56,
                display_as_bot = True,
                editable = True,
                editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                external_id = '',
                external_type = '',
                external_url = '',
                filetype = '',
                groups = [
                    'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                    ],
                has_rich_preview = True,
                id = 'FQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0',
                image_exif_rotation = 56,
                ims = [
                    'DQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                    ],
                is_external = True,
                is_public = True,
                is_starred = True,
                is_tombstoned = True,
                last_editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                mimetype = '',
                mode = '',
                name = '',
                non_owner_editable = True,
                num_stars = 56,
                original_h = 56,
                original_w = 56,
                permalink = '',
                permalink_public = '',
                pinned_info = slack_beta_ti.models.info_for_a_pinned_item.Info for a pinned item(),
                pinned_to = [
                    'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                    ],
                pretty_type = '',
                preview = '',
                public_url_shared = True,
                reactions = [
                    slack_beta_ti.models.reaction_object.Reaction object(
                        count = 56, 
                        name = '', 
                        users = [
                            'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                            ], )
                    ],
                shares = None,
                size = 56,
                source_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                state = '',
                thumb_1024 = '',
                thumb_1024_h = 56,
                thumb_1024_w = 56,
                thumb_160 = '',
                thumb_360 = '',
                thumb_360_h = 56,
                thumb_360_w = 56,
                thumb_480 = '',
                thumb_480_h = 56,
                thumb_480_w = 56,
                thumb_64 = '',
                thumb_720 = '',
                thumb_720_h = 56,
                thumb_720_w = 56,
                thumb_80 = '',
                thumb_800 = '',
                thumb_800_h = 56,
                thumb_800_w = 56,
                thumb_960 = '',
                thumb_960_h = 56,
                thumb_960_w = 56,
                thumb_tiny = '',
                timestamp = 56,
                title = '',
                updated = 56,
                url_private = '',
                url_private_download = '',
                user = '',
                user_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                username = ''
            )
        else:
            return ObjsFile(
        )
        """

    def testObjsFile(self):
        """Test ObjsFile"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.api.admin_teams_settings_api import AdminTeamsSettingsApi


class TestAdminTeamsSettingsApi(unittest.TestCase):
    """AdminTeamsSettingsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AdminTeamsSettingsApi()

    def tearDown(self) -> None:
        pass

    def test_admin_teams_settings_info(self) -> None:
        """Test case for admin_teams_settings_info

        """
        pass

    def test_admin_teams_settings_set_default_channels(self) -> None:
        """Test case for admin_teams_settings_set_default_channels

        """
        pass

    def test_admin_teams_settings_set_description(self) -> None:
        """Test case for admin_teams_settings_set_description

        """
        pass

    def test_admin_teams_settings_set_discoverability(self) -> None:
        """Test case for admin_teams_settings_set_discoverability

        """
        pass

    def test_admin_teams_settings_set_icon(self) -> None:
        """Test case for admin_teams_settings_set_icon

        """
        pass

    def test_admin_teams_settings_set_name(self) -> None:
        """Test case for admin_teams_settings_set_name

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ChatPostMessageRequest(BaseModel):
    """
    ChatPostMessageRequest
    """ # noqa: E501
    as_user: Optional[StrictStr] = Field(default=None, description="Pass true to post the message as the authed user, instead of as a bot. Defaults to false. See [authorship](#authorship) below.")
    attachments: Optional[StrictStr] = Field(default=None, description="A JSON-based array of structured attachments, presented as a URL-encoded string.")
    blocks: Optional[StrictStr] = Field(default=None, description="A JSON-based array of structured blocks, presented as a URL-encoded string.")
    channel: StrictStr = Field(description="Channel, private group, or IM channel to send message to. Can be an encoded ID, or a name. See [below](#channels) for more details.")
    icon_emoji: Optional[StrictStr] = Field(default=None, description="Emoji to use as the icon for this message. Overrides `icon_url`. Must be used in conjunction with `as_user` set to `false`, otherwise ignored. See [authorship](#authorship) below.")
    icon_url: Optional[StrictStr] = Field(default=None, description="URL to an image to use as the icon for this message. Must be used in conjunction with `as_user` set to false, otherwise ignored. See [authorship](#authorship) below.")
    link_names: Optional[StrictBool] = Field(default=None, description="Find and link channel names and usernames.")
    mrkdwn: Optional[StrictBool] = Field(default=None, description="Disable Slack markup parsing by setting to `false`. Enabled by default.")
    parse: Optional[StrictStr] = Field(default=None, description="Change how messages are treated. Defaults to `none`. See [below](#formatting).")
    reply_broadcast: Optional[StrictBool] = Field(default=None, description="Used in conjunction with `thread_ts` and indicates whether reply should be made visible to everyone in the channel or conversation. Defaults to `false`.")
    text: Optional[StrictStr] = Field(default=None, description="How this field works and whether it is required depends on other fields you use in your API call. [See below](#text_usage) for more detail.")
    thread_ts: Optional[StrictStr] = Field(default=None, description="Provide another message's `ts` value to make this message a reply. Avoid using a reply's `ts` value; use its parent instead.")
    unfurl_links: Optional[StrictBool] = Field(default=None, description="Pass true to enable unfurling of primarily text-based content.")
    unfurl_media: Optional[StrictBool] = Field(default=None, description="Pass false to disable unfurling of media content.")
    username: Optional[StrictStr] = Field(default=None, description="Set your bot's user name. Must be used in conjunction with `as_user` set to false, otherwise ignored. See [authorship](#authorship) below.")
    __properties: ClassVar[List[str]] = ["as_user", "attachments", "blocks", "channel", "icon_emoji", "icon_url", "link_names", "mrkdwn", "parse", "reply_broadcast", "text", "thread_ts", "unfurl_links", "unfurl_media", "username"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ChatPostMessageRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ChatPostMessageRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "as_user": obj.get("as_user"),
            "attachments": obj.get("attachments"),
            "blocks": obj.get("blocks"),
            "channel": obj.get("channel"),
            "icon_emoji": obj.get("icon_emoji"),
            "icon_url": obj.get("icon_url"),
            "link_names": obj.get("link_names"),
            "mrkdwn": obj.get("mrkdwn"),
            "parse": obj.get("parse"),
            "reply_broadcast": obj.get("reply_broadcast"),
            "text": obj.get("text"),
            "thread_ts": obj.get("thread_ts"),
            "unfurl_links": obj.get("unfurl_links"),
            "unfurl_media": obj.get("unfurl_media"),
            "username": obj.get("username")
        })
        return _obj





# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.api.admin_api import AdminApi


class TestAdminApi(unittest.TestCase):
    """AdminApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AdminApi()

    def tearDown(self) -> None:
        pass

    def test_admin_apps_approve(self) -> None:
        """Test case for admin_apps_approve

        """
        pass

    def test_admin_apps_approved_list(self) -> None:
        """Test case for admin_apps_approved_list

        """
        pass

    def test_admin_apps_requests_list(self) -> None:
        """Test case for admin_apps_requests_list

        """
        pass

    def test_admin_apps_restrict(self) -> None:
        """Test case for admin_apps_restrict

        """
        pass

    def test_admin_apps_restricted_list(self) -> None:
        """Test case for admin_apps_restricted_list

        """
        pass

    def test_admin_conversations_archive(self) -> None:
        """Test case for admin_conversations_archive

        """
        pass

    def test_admin_conversations_convert_to_private(self) -> None:
        """Test case for admin_conversations_convert_to_private

        """
        pass

    def test_admin_conversations_create(self) -> None:
        """Test case for admin_conversations_create

        """
        pass

    def test_admin_conversations_delete(self) -> None:
        """Test case for admin_conversations_delete

        """
        pass

    def test_admin_conversations_disconnect_shared(self) -> None:
        """Test case for admin_conversations_disconnect_shared

        """
        pass

    def test_admin_conversations_ekm_list_original_connected_channel_info(self) -> None:
        """Test case for admin_conversations_ekm_list_original_connected_channel_info

        """
        pass

    def test_admin_conversations_get_conversation_prefs(self) -> None:
        """Test case for admin_conversations_get_conversation_prefs

        """
        pass

    def test_admin_conversations_get_teams(self) -> None:
        """Test case for admin_conversations_get_teams

        """
        pass

    def test_admin_conversations_invite(self) -> None:
        """Test case for admin_conversations_invite

        """
        pass

    def test_admin_conversations_rename(self) -> None:
        """Test case for admin_conversations_rename

        """
        pass

    def test_admin_conversations_restrict_access_add_group(self) -> None:
        """Test case for admin_conversations_restrict_access_add_group

        """
        pass

    def test_admin_conversations_restrict_access_list_groups(self) -> None:
        """Test case for admin_conversations_restrict_access_list_groups

        """
        pass

    def test_admin_conversations_restrict_access_remove_group(self) -> None:
        """Test case for admin_conversations_restrict_access_remove_group

        """
        pass

    def test_admin_conversations_search(self) -> None:
        """Test case for admin_conversations_search

        """
        pass

    def test_admin_conversations_set_conversation_prefs(self) -> None:
        """Test case for admin_conversations_set_conversation_prefs

        """
        pass

    def test_admin_conversations_set_teams(self) -> None:
        """Test case for admin_conversations_set_teams

        """
        pass

    def test_admin_conversations_unarchive(self) -> None:
        """Test case for admin_conversations_unarchive

        """
        pass

    def test_admin_emoji_add(self) -> None:
        """Test case for admin_emoji_add

        """
        pass

    def test_admin_emoji_add_alias(self) -> None:
        """Test case for admin_emoji_add_alias

        """
        pass

    def test_admin_emoji_list(self) -> None:
        """Test case for admin_emoji_list

        """
        pass

    def test_admin_emoji_remove(self) -> None:
        """Test case for admin_emoji_remove

        """
        pass

    def test_admin_emoji_rename(self) -> None:
        """Test case for admin_emoji_rename

        """
        pass

    def test_admin_invite_requests_approve(self) -> None:
        """Test case for admin_invite_requests_approve

        """
        pass

    def test_admin_invite_requests_approved_list(self) -> None:
        """Test case for admin_invite_requests_approved_list

        """
        pass

    def test_admin_invite_requests_denied_list(self) -> None:
        """Test case for admin_invite_requests_denied_list

        """
        pass

    def test_admin_invite_requests_deny(self) -> None:
        """Test case for admin_invite_requests_deny

        """
        pass

    def test_admin_invite_requests_list(self) -> None:
        """Test case for admin_invite_requests_list

        """
        pass

    def test_admin_teams_admins_list(self) -> None:
        """Test case for admin_teams_admins_list

        """
        pass

    def test_admin_teams_create(self) -> None:
        """Test case for admin_teams_create

        """
        pass

    def test_admin_teams_list(self) -> None:
        """Test case for admin_teams_list

        """
        pass

    def test_admin_teams_owners_list(self) -> None:
        """Test case for admin_teams_owners_list

        """
        pass

    def test_admin_teams_settings_info(self) -> None:
        """Test case for admin_teams_settings_info

        """
        pass

    def test_admin_teams_settings_set_default_channels(self) -> None:
        """Test case for admin_teams_settings_set_default_channels

        """
        pass

    def test_admin_teams_settings_set_description(self) -> None:
        """Test case for admin_teams_settings_set_description

        """
        pass

    def test_admin_teams_settings_set_discoverability(self) -> None:
        """Test case for admin_teams_settings_set_discoverability

        """
        pass

    def test_admin_teams_settings_set_icon(self) -> None:
        """Test case for admin_teams_settings_set_icon

        """
        pass

    def test_admin_teams_settings_set_name(self) -> None:
        """Test case for admin_teams_settings_set_name

        """
        pass

    def test_admin_usergroups_add_channels(self) -> None:
        """Test case for admin_usergroups_add_channels

        """
        pass

    def test_admin_usergroups_add_teams(self) -> None:
        """Test case for admin_usergroups_add_teams

        """
        pass

    def test_admin_usergroups_list_channels(self) -> None:
        """Test case for admin_usergroups_list_channels

        """
        pass

    def test_admin_usergroups_remove_channels(self) -> None:
        """Test case for admin_usergroups_remove_channels

        """
        pass

    def test_admin_users_assign(self) -> None:
        """Test case for admin_users_assign

        """
        pass

    def test_admin_users_invite(self) -> None:
        """Test case for admin_users_invite

        """
        pass

    def test_admin_users_list(self) -> None:
        """Test case for admin_users_list

        """
        pass

    def test_admin_users_remove(self) -> None:
        """Test case for admin_users_remove

        """
        pass

    def test_admin_users_session_invalidate(self) -> None:
        """Test case for admin_users_session_invalidate

        """
        pass

    def test_admin_users_session_reset(self) -> None:
        """Test case for admin_users_session_reset

        """
        pass

    def test_admin_users_set_admin(self) -> None:
        """Test case for admin_users_set_admin

        """
        pass

    def test_admin_users_set_expiration(self) -> None:
        """Test case for admin_users_set_expiration

        """
        pass

    def test_admin_users_set_owner(self) -> None:
        """Test case for admin_users_set_owner

        """
        pass

    def test_admin_users_set_regular(self) -> None:
        """Test case for admin_users_set_regular

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class ObjsSubteam(BaseModel):
    """
    ObjsSubteam
    """ # noqa: E501
    auto_provision: StrictBool
    auto_type: Dict[str, Any]
    channel_count: Optional[StrictInt] = None
    created_by: Annotated[str, Field(strict=True)]
    date_create: StrictInt
    date_delete: StrictInt
    date_update: StrictInt
    deleted_by: Dict[str, Any]
    description: StrictStr
    enterprise_subteam_id: StrictStr
    handle: StrictStr
    id: Annotated[str, Field(strict=True)]
    is_external: StrictBool
    is_subteam: StrictBool
    is_usergroup: StrictBool
    name: StrictStr
    prefs: Dict[str, Any]
    team_id: Annotated[str, Field(strict=True)]
    updated_by: Annotated[str, Field(strict=True)]
    user_count: Optional[StrictInt] = None
    users: Optional[List[Annotated[str, Field(strict=True)]]] = None
    __properties: ClassVar[List[str]] = ["auto_provision", "auto_type", "channel_count", "created_by", "date_create", "date_delete", "date_update", "deleted_by", "description", "enterprise_subteam_id", "handle", "id", "is_external", "is_subteam", "is_usergroup", "name", "prefs", "team_id", "updated_by", "user_count", "users"]

    @field_validator('created_by')
    def created_by_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[UW][A-Z0-9]{2,}$", value):
            raise ValueError(r"must validate the regular expression /^[UW][A-Z0-9]{2,}$/")
        return value

    @field_validator('id')
    def id_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^S[A-Z0-9]{2,}$", value):
            raise ValueError(r"must validate the regular expression /^S[A-Z0-9]{2,}$/")
        return value

    @field_validator('team_id')
    def team_id_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[T][A-Z0-9]{2,}$", value):
            raise ValueError(r"must validate the regular expression /^[T][A-Z0-9]{2,}$/")
        return value

    @field_validator('updated_by')
    def updated_by_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[UW][A-Z0-9]{2,}$", value):
            raise ValueError(r"must validate the regular expression /^[UW][A-Z0-9]{2,}$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ObjsSubteam from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ObjsSubteam from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "auto_provision": obj.get("auto_provision"),
            "auto_type": obj.get("auto_type"),
            "channel_count": obj.get("channel_count"),
            "created_by": obj.get("created_by"),
            "date_create": obj.get("date_create"),
            "date_delete": obj.get("date_delete"),
            "date_update": obj.get("date_update"),
            "deleted_by": obj.get("deleted_by"),
            "description": obj.get("description"),
            "enterprise_subteam_id": obj.get("enterprise_subteam_id"),
            "handle": obj.get("handle"),
            "id": obj.get("id"),
            "is_external": obj.get("is_external"),
            "is_subteam": obj.get("is_subteam"),
            "is_usergroup": obj.get("is_usergroup"),
            "name": obj.get("name"),
            "prefs": obj.get("prefs"),
            "team_id": obj.get("team_id"),
            "updated_by": obj.get("updated_by"),
            "user_count": obj.get("user_count"),
            "users": obj.get("users")
        })
        return _obj





# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.api.files_remote_api import FilesRemoteApi


class TestFilesRemoteApi(unittest.TestCase):
    """FilesRemoteApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FilesRemoteApi()

    def tearDown(self) -> None:
        pass

    def test_files_remote_add(self) -> None:
        """Test case for files_remote_add

        """
        pass

    def test_files_remote_info(self) -> None:
        """Test case for files_remote_info

        """
        pass

    def test_files_remote_list(self) -> None:
        """Test case for files_remote_list

        """
        pass

    def test_files_remote_remove(self) -> None:
        """Test case for files_remote_remove

        """
        pass

    def test_files_remote_share(self) -> None:
        """Test case for files_remote_share

        """
        pass

    def test_files_remote_update(self) -> None:
        """Test case for files_remote_update

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.api.admin_conversations_api import AdminConversationsApi


class TestAdminConversationsApi(unittest.TestCase):
    """AdminConversationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AdminConversationsApi()

    def tearDown(self) -> None:
        pass

    def test_admin_conversations_archive(self) -> None:
        """Test case for admin_conversations_archive

        """
        pass

    def test_admin_conversations_convert_to_private(self) -> None:
        """Test case for admin_conversations_convert_to_private

        """
        pass

    def test_admin_conversations_create(self) -> None:
        """Test case for admin_conversations_create

        """
        pass

    def test_admin_conversations_delete(self) -> None:
        """Test case for admin_conversations_delete

        """
        pass

    def test_admin_conversations_disconnect_shared(self) -> None:
        """Test case for admin_conversations_disconnect_shared

        """
        pass

    def test_admin_conversations_get_conversation_prefs(self) -> None:
        """Test case for admin_conversations_get_conversation_prefs

        """
        pass

    def test_admin_conversations_get_teams(self) -> None:
        """Test case for admin_conversations_get_teams

        """
        pass

    def test_admin_conversations_invite(self) -> None:
        """Test case for admin_conversations_invite

        """
        pass

    def test_admin_conversations_rename(self) -> None:
        """Test case for admin_conversations_rename

        """
        pass

    def test_admin_conversations_search(self) -> None:
        """Test case for admin_conversations_search

        """
        pass

    def test_admin_conversations_set_conversation_prefs(self) -> None:
        """Test case for admin_conversations_set_conversation_prefs

        """
        pass

    def test_admin_conversations_set_teams(self) -> None:
        """Test case for admin_conversations_set_teams

        """
        pass

    def test_admin_conversations_unarchive(self) -> None:
        """Test case for admin_conversations_unarchive

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.models.objs_subteam import ObjsSubteam

class TestObjsSubteam(unittest.TestCase):
    """ObjsSubteam unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ObjsSubteam:
        """Test ObjsSubteam
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ObjsSubteam`
        """
        model = ObjsSubteam()
        if include_optional:
            return ObjsSubteam(
                auto_provision = True,
                auto_type = None,
                channel_count = 56,
                created_by = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                date_create = 56,
                date_delete = 56,
                date_update = 56,
                deleted_by = None,
                description = '',
                enterprise_subteam_id = '',
                handle = '',
                id = 'S8Q6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKT',
                is_external = True,
                is_subteam = True,
                is_usergroup = True,
                name = '',
                prefs = None,
                team_id = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                updated_by = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                user_count = 56,
                users = [
                    'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                    ]
            )
        else:
            return ObjsSubteam(
                auto_provision = True,
                auto_type = None,
                created_by = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                date_create = 56,
                date_delete = 56,
                date_update = 56,
                deleted_by = None,
                description = '',
                enterprise_subteam_id = '',
                handle = '',
                id = 'S8Q6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKT',
                is_external = True,
                is_subteam = True,
                is_usergroup = True,
                name = '',
                prefs = None,
                team_id = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                updated_by = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
        )
        """

    def testObjsSubteam(self):
        """Test ObjsSubteam"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
